webbpsf\_ext.robust
===================

.. automodule:: webbpsf_ext.robust

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      biweightMean
      checkfit
      linefit
      mean
      medabsdev
      mode
      polyfit
      std
   
   

   
   
   

   
   
   



